Python vSphere Client with a dialog(1) interface
================================================

.. image:: https://badges.gitter.im/Join%20Chat.svg
   :alt: Join the chat at https://gitter.im/dnaeon/pvc
   :target: https://gitter.im/dnaeon/pvc?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

PVC is an interactive text-mode VMware vSphere Client with a
`dialog(1)`_ interface for GNU/Linux systems built on top of the
`pyVmomi`_ VMware vSphere API Python bindings.

Using PVC allows you to quickly navigate in your VMware vSphere
environment and perform common tasks against various VMware vSphere
Managed Entities.

PVC is Open Source and licensed under the `BSD License`_.

.. image:: https://raw.githubusercontent.com/dnaeon/pvc/master/docs/images/pvc-screenshot.jpg

Status
======

Experimental. PVC is in early development stage. Using PVC in a
production environment is not (yet) recommended.

Contributions
=============

PVC is hosted on `Github`_. Please contribute by reporting issues,
suggesting features or by sending patches using pull requests.

Documentation
=============

The online documentation of PVC can be found at the link below:

* http://pvc.readthedocs.org/en/latest/

At the above link you can also find example screenshots of using
PVC in a VMware vSphere environment.

Bugs
====

Probably. If you experience a bug issue, please report it to the
PVC issue tracker on `Github`_.

.. _`dialog(1)`: http://invisible-island.net/dialog/
.. _`pyVmomi`: https://github.com/vmware/pyvmomi
.. _`BSD License`: http://opensource.org/licenses/BSD-2-Clause
.. _`Github`: https://github.com/dnaeon/pvc

